# Installation

You can install Dynamiqs with `pip`:

```shell
pip install dynamiqs
```

!!! Note
    If you're using a GPU, please refer to the [JAX installation](https://jax.readthedocs.io/en/latest/installation.html) documentation page for detailed instructions on how to install JAX for your device.
